# hpc-helper

[![PyPI](https://img.shields.io/pypi/v/hpc-helper)](https://pypi.org/project/hpc-helper/)
![GitHub](https://img.shields.io/github/license/mad-lab-fau/hpc-helper)
[![Test and Lint](https://github.com/mad-lab-fau/hpc-helper/actions/workflows/test-and-lint.yml/badge.svg)](https://github.com/mad-lab-fau/hpc-helper/actions/workflows/test-and-lint.yml)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
![PyPI - Downloads](https://img.shields.io/pypi/dm/hpc-helper)
![GitHub commit activity](https://img.shields.io/github/commit-activity/m/mad-lab-fau/hpc-helper)

Python package with helper functions for working with FAU's [High Performance Cluster](https://hpc.fau.de/) (HPC).

## Installation

``hpc-helper`` requires Python >=3.7. First, install a compatible version of Python. 
Then you can install ``hpc-helper`` via pip. 

Installation from [PyPi](https://pypi.org/): 
```bash
pip install hpc_helper
```

Installation from local repository copy:
```bash
git clone https://github.com/mad-lab-fau/hpc-helper.git
cd hpc_helper
pip install .
```
